'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lib = require('../../lib');

var _PropTypes = require('../../lib/PropTypes');

exports.default = {
  name: 'SuiImage',
  mixins: [_lib.SemanticUIVueMixin],
  props: {
    avatar: {
      type: Boolean,
      description: 'An image may be formatted to appear inline with text as an avatar.'
    },
    bordered: {
      type: Boolean,
      description: 'An image may include a border to emphasize the edges of white or transparent content.'
    },
    circular: {
      type: Boolean,
      description: 'An image may appear circular.'
    },
    rounded: {
      type: Boolean,
      description: 'An image may appear rounded.'
    },
    disabled: Boolean,
    hidden: Boolean,
    size: _PropTypes.Enum.Size(),
    spaced: (0, _PropTypes.Enum)(['left', 'right'], { type: Boolean }),
    shape: (0, _PropTypes.Enum)(['rounded', 'circular']),
    src: {
      type: String,
      required: true
    },
    floated: (0, _PropTypes.Enum)(['left', 'right']),
    centered: Boolean,
    verticalAlign: _PropTypes.Enum.VerticalAlign({
      description: 'An image can specify its vertical alignment.'
    }),
    wrapped: Boolean
  },
  render: function render() {
    var h = arguments[0];

    var ElementType = this.getElementType('div');
    var classNames = this.classes('ui', this.avatar && 'avatar', this.size, this.shape, this.verticalAlign && this.verticalAlign + ' aligned', this.floated && this.floated + ' floated', this.centered && 'centered', this.bordered && 'bordered', this.rounded && 'rounded', this.circular && 'circular', this.spaced, this.spaced && 'spaced', this.hidden && 'hidden', this.disabled && 'disabled', 'image');

    if (this.wrapped || this.$slots.corner || this.$slots.label) {
      return h(
        ElementType,
        { 'class': classNames },
        [this.$slots.corner, h('img', {
          attrs: { src: this.src }
        }), this.$slots.label]
      );
    }

    return h('img', { 'class': classNames, attrs: { src: this.src }
    });
  }
};